==> mx-repo-manager_23.11.tar.xz: BUILD/translations/mx-repo-manager_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX-Paketquellen-Verwaltung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="623"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Wählen sie die APT-Paketquelle, die sie verwenden möchten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX-Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Schnellste MX-Paketquelle auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian-Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Automatische Wahl des schnellsten gerade verfügbaren Debian-Paketquellen-Servers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Einzelquellen </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Wiederherstellung der originalen APT-Quellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ihre neue Auswahl wird wirksam wenn die Quellen nächstes Mal aktualisiert werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Lists</source>
        <translation>Listen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Quellen (Kästchen mit Haken sind aktiviert)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <location filename="../mainwindow.cpp" line="678"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="743"/>
        <location filename="../mainwindow.cpp" line="749"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Could not change the repo.</source>
        <translation>Wechsel des Paketquellen-Servers nicht möglich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programm zur Wahl der Standard-Paketquelle für APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Sie haben die MX-Testpaketquellen ausgewählt. Es wird nicht empfohlen, sie aktiviert zu lassen oder alle Pakete davon zu aktualisieren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ein sichererer Weg ist die Installation von einzelnen Paketen mit der MX-Paketinstallation.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Wählen sie die APT-Paketquelle und Quellen, die sie verwenden möchten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt konnte die schnellste Paketquelle nicht erkennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>Could not detect fastest repo.</source>
        <translation>Die schnellste Paketquelle konnte nicht erkannt werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Ich kann nicht feststellen, ob diese App auf antiX oder MX läuft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX version nicht erkannt oder außerhalb des Bereichs:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Could not download original APT files.</source>
        <translation>Die originalen APT-Dateien konnten nicht heruntergeladen werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Konnte die heruntergeladene Datei nicht entpacken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Enabling AHS</source>
        <translation>AHS aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Benutzen sie die AHS (Advanced Hardware Stack)-Paketquellen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="767"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Die originalen APT-Quellen wurden in den Ausgangsstatus zurückgesetzt. Benutzerdefinierte Quelldateien in /etc/apt/sources.list.d/ wurden nicht berührt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Beim Schreiben der Datei %1 gab es einen Fehler. Bitte prüfen sie, ob genügend freier Speicherplatz auf dem Laufwerk vorhanden ist</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <location filename="../main.cpp" line="84"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Administrator am System angemeldet. Bitte melden sie sich ab und dann als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-repo-manager_24.3.tar.xz: BUILD/translations/mx-repo-manager_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>MX Repo Manager</source>
        <translation>MX-Paketquellen-Verwaltung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Wählen Sie die APT-Paketquelle, die Sie verwenden möchten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX-Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Schnellste MX-Paketquelle auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian-Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Automatische Wahl des schnellsten gerade verfügbaren Debian-Paketquellen-Servers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Einzelquellen </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Wiederherstellung der originalen APT-Quellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="761"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ihre neue Auswahl wird erst bei der nächsten Aktualisierung der Quellen wirksam.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Lists</source>
        <translation>Listen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Quellen (Kästchen mit Haken sind aktiviert)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <location filename="../mainwindow.cpp" line="714"/>
        <location filename="../mainwindow.cpp" line="721"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <location filename="../mainwindow.cpp" line="744"/>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Could not change the repo.</source>
        <translation>Wechsel des Paketquellen-Servers nicht möglich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programm zur Wahl der Standard-Paketquelle für APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Sie haben die MX-Testpaketquellen ausgewählt. Es wird nicht empfohlen, sie aktiviert zu lassen oder alle Pakete davon zu aktualisieren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ein sichererer Weg ist die Installation von einzelnen Paketen mit der MX-Paketinstallation.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Wählen Sie die APT-Paketquelle und Quellen, die Sie verwenden möchten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt konnte die schnellste Paketquelle nicht erkennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <source>Could not detect fastest repo.</source>
        <translation>Die schnellste Paketquelle konnte nicht erkannt werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Ich kann nicht feststellen, ob diese App auf antiX oder MX läuft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX version nicht erkannt oder außerhalb des Bereichs:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Could not download original APT files.</source>
        <translation>Die originalen APT-Dateien konnten nicht heruntergeladen werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="744"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Konnte die heruntergeladene Datei nicht entpacken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Enabling AHS</source>
        <translation>AHS aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Benutzen Sie die AHS (Advanced Hardware Stack)-Paketquellen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="762"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Die originalen APT-Quellen wurden in den Ausgangsstatus zurückgesetzt. Benutzerdefinierte Quelldateien in /etc/apt/sources.list.d/ wurden nicht berührt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Beim Schreiben der Datei %1 gab es einen Fehler. Bitte prüfen Sie, ob genügend freier Speicherplatz auf dem Laufwerk vorhanden ist</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Administrator am System angemeldet. Bitte melden Sie sich ab und dann als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Diese Anwendung muss mit Administratorrechten ausgeführt werden.</translation>
    </message>
</context>
</TS>
